package com.lyg.application.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lyg.application.entity.TaSourceAttach;
import com.lyg.application.service.TaSourceAttachService;
import com.lyg.common.util.StringUtil;
import com.lyg.framework.accesslimit.AccessLimit;
import com.lyg.framework.log.OpLog;
import com.lyg.system.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 搜索附件表;(ta_search_attach)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2024-3-22
 */
@Api(tags = "搜索附件表对象功能接口")
@RestController
@RequestMapping("/")
public class TaSourceAttachController extends BaseController {

    @Autowired
    private TaSourceAttachService taSourceAttachService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "搜索附件表", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taSearchAttach/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return SaResult.data(taSourceAttachService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "搜索附件表", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/taSearchAttach")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                         @ApiParam("正序排列") @RequestParam(value = "sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value = "sortDesc", defaultValue = "created_time") String sortDesc) throws Exception {

        IPage<TaSourceAttach> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaSourceAttach> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<TaSourceAttach> result = taSourceAttachService.page(pg, queryWrapper);

        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param TaSourceAttach 实例对象
     * @return 实例对象
     */
    @OpLog(module = "搜索附件表", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/taSearchAttach")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody TaSourceAttach TaSourceAttach) throws Exception {
        taSourceAttachService.save(TaSourceAttach);
        return SaResult.data(TaSourceAttach);
    }

    /**
     * 更新数据
     *
     * @param taSearchAttach 实例对象
     * @return 实例对象
     */
    @OpLog(module = "搜索附件表", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/taSearchAttach/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody TaSourceAttach TaSourceAttach,
                         @ApiParam("对象ID") @PathVariable String id) throws Exception {
        TaSourceAttach.setSourceAttachId(id);
        taSourceAttachService.updateById(TaSourceAttach);
        return SaResult.data(TaSourceAttach);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "搜索附件表", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taSearchAttach/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id) {
        taSourceAttachService.removeById(id);
        return SaResult.data("success");
    }
}